/* ----------------------------------------------------------
                           keypad.h

     Header fuer das Einlesen von 4 (als Gamepad
     angeordnete) Tasten.

     Ein Doppelklicken der Taste nach oben wird als
     Enter ausgewertet.

     MCU   : AVR
     Takt  :


     07.03.2020  R. Seelig
   ---------------------------------------------------------- */

#ifndef in_keypad
  #define in_keypad

  #include "sysf103_init.h"

  #define boardvers   10

  #if (boardvers == 10)
    // Steckbrettvariante uc-Net

    // ----------------- Spieltasten ---------------
    /* Belegung Tastenpins:
                       PB7  = Taster links
                       PC14 = Taster up
                       PA0  = Taster down
                       PC15 = Taster rechts
                       PC14 Doppelklick = Enter
    */

    #define keyleft_init()     PB7_input_init()
    #define is_keyleft()       !(is_PB7())

    #define keyup_init()       PC14_input_init()
    #define is_keyup()         !(is_PC14())

    #define keydwn_init()      PA0_input_init()
    #define is_keydwn()        !(is_PA0())

    #define keyright_init()    PC15_input_init()
    #define is_keyright()      !(is_PC15())


  #else
    #error "Keine Boardversion fuer Tasten angegeben"
  #endif

  #define entpr_time         60           // Tastenentprellzeit in mS
  #define double_klicktime   100           // Zeit, die ein Doppelklick auf die Taste UP verstreichen
                                          // darf, um sie als Doppelklick zu erkennen

  // Tastenzuordnung
  enum { NO_KEY, UP, LEFT, RIGHT, DOWN, ENTER };

/* ----------------------------------------------------------
                           Prototypen
   ---------------------------------------------------------- */

  void key_init(void);
  uint8_t key_get(void);


#endif
